You are viewing a plain text version of this content. The canonical link for it is here.
Posted to issues@hbase.apache.org by "Todd Lipcon (JIRA)" <ji...@apache.org> on 2012/04/29 04:30:48 UTC

[jira] [Commented] (HBASE-5897) prePut coprocessor hook causing substantial CPU usage

    [ https://issues.apache.org/jira/browse/HBASE-5897?page=com.atlassian.jira.plugin.system.issuetabpanels:comment-tabpanel&focusedCommentId=13264449#comment-13264449 ] 

Todd Lipcon commented on HBASE-5897:
------------------------------------

Test methodology: I'm running a single standalone HBase on local filesystem. I rm the dir from /tmp, then start the master, create a table with a single column family, then restart the master with "time bin/hbase master". I then insert 1M rows from YCSB, and hit ^C on the master. I ran the test with the preput hook left in, and with it commented out, and flipped between the two setups twice to make sure I could reproduce. I'm reporting the user and system CPU here, since the wall clock time is sensitive to how quickly I ran the commands.

with hook commented out:
run 1:
user    1m57.760s
sys     0m3.300s
run 2:
user    1m54.840s
sys     0m3.870s


with cp hook left in:
run 1:
user    3m13.890s
sys     0m3.940s
run 2:
user    3m11.960s
sys     0m3.930s

I also re-ran the original oprofile analysis and "doMiniBatchPut" basically dropped off the CPU profile results once I made this change.

I verified for sure that I have no coprocessors installed by adding a println in RegionCoprocessorHost - it didn't print out.
                
> prePut coprocessor hook causing substantial CPU usage
> -----------------------------------------------------
>
>                 Key: HBASE-5897
>                 URL: https://issues.apache.org/jira/browse/HBASE-5897
>             Project: HBase
>          Issue Type: Bug
>    Affects Versions: 0.92.0
>            Reporter: Todd Lipcon
>
> I was running an insert workload against trunk under oprofile and saw that a significant portion of CPU usage was going to calling the "prePut" coprocessor hook inside doMiniBatchPut, even though I don't have any coprocessors installed. I ran a million-row insert and collected CPU time spent in the RS after commenting out the preput hook, and found CPU usage reduced by 33%.

--
This message is automatically generated by JIRA.
If you think it was sent incorrectly, please contact your JIRA administrators: https://issues.apache.org/jira/secure/ContactAdministrators!default.jspa
For more information on JIRA, see: http://www.atlassian.com/software/jira